# coding: utf-8

"""


    Generated by: https://konfigthis.com
"""

import unittest
from unittest.mock import patch

import urllib3

import decentro_in_kyc_client
from decentro_in_kyc_client.paths.kyc_scan_extract_ocr import post
from decentro_in_kyc_client import configuration, schemas, api_client

from .. import ApiTestMixin


class TestKycScanExtractOcr(ApiTestMixin, unittest.TestCase):
    """
    KycScanExtractOcr unit test stubs
        Scan & Extract
    """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    response_status = 200




if __name__ == '__main__':
    unittest.main()
