# coding: utf-8

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

import unittest

import decentro_in_kyc_client
from decentro_in_kyc_client.model.check_image_quality_request import CheckImageQualityRequest
from decentro_in_kyc_client import configuration


class TestCheckImageQualityRequest(unittest.TestCase):
    """CheckImageQualityRequest unit test stubs"""
    pass


if __name__ == '__main__':
    unittest.main()
