# coding: utf-8

# flake8: noqa

"""
    decentro-in-kyc

    KYC & Onboarding

    The version of the OpenAPI document: 1.0.0
    Contact: admin@decentro.tech
    Created by: https://decentro.tech
"""

__version__ = "4.1.0"

# import ApiClient
from decentro_in_kyc_client.api_client import ApiClient

# import Configuration
from decentro_in_kyc_client.configuration import Configuration

# import exceptions
from decentro_in_kyc_client.exceptions import OpenApiException
from decentro_in_kyc_client.exceptions import ApiAttributeError
from decentro_in_kyc_client.exceptions import ApiTypeError
from decentro_in_kyc_client.exceptions import ApiValueError
from decentro_in_kyc_client.exceptions import ApiKeyError
from decentro_in_kyc_client.exceptions import ApiException

from decentro_in_kyc_client.client import Decentro
